# -*- coding: utf-8 -*-
#! /usr/bin/python2.7
#----------------------------------------------------------------
# Dateiname: fruits.py
# Das RPi-Kameramodul ist angeschlossen.
# Das Programm erkennt Früchte an ihrer Farbe.
# 
# Michael Weigend: Raspberry Pi programmieren mit Python, mitp 2013
# 10.7
# 29.10.2013
#----------------------------------------------------------------

import os, time 
from Tkinter import Tk, Label, Button, W,LEFT
from PIL import Image, ImageTk
from color import Color
WIDTH, HEIGHT = 800, 600
BBOX = (200,150,600, 450)
GRID = 10
GREY = Color(70, 70, 70)
PATH = '/home/pi/photos/image.jpg'

class FruitIdentifier:
    fruits = {Color(255, 0, 0): 'Tomaten oder Kirschen',
              Color(255, 255, 0):'Bananen oder Zitronen',
              Color(0, 255, 0):'Äpfel (Granny Smith)',
              Color(0, 0, 220): 'Brombeeren',
              Color(255, 120, 10):'Orangen'}

    def __init__(self):
        self.frequency = dict()
        for c in self.fruits.keys():
            self.frequency[c] = 0
    
    def identify(self, photo):
        img = photo.load()
        width, height = photo.size
        for x in range(width//GRID):
            for y in range(height//GRID):
                r, g, b = img[x*GRID, y*GRID]
                pixColor = Color(r, g, b)
                self.checkColor(pixColor)
        for c, n in self.frequency.items():
            if n == max(self.frequency.values()):
                return self.fruits[c]

    def checkColor(self, pixColor):
        for c in self.fruits.keys():
            if c - GREY < pixColor < c + GREY:
                self.frequency[c] += 1
        
class App:  
    def __init__(self):
        # Widgets
        self.window = Tk()
        self.labelImage = Label(master=self.window)
        self.labelImage.pack()
        self.label= Label(master=self.window,
                          text='Welche Früchte sind das?')
        self.label.pack()
        self.button = Button(master=self.window, text='Prüfen',
                             command=self.check)
        self.button.pack()
        self.takePhoto()
        self.window.mainloop()
    
    def takePhoto (self):
        command = 'raspistill -t 500 -w %s -h %s -o %s -n '
        os.system(command % (WIDTH, HEIGHT, PATH))
        self.image = Image.open(PATH).crop(BBOX)
        self.pImage=ImageTk.PhotoImage(self.image)    
        self.labelImage.config(image=self.pImage)
        self.window.after(1000, self.takePhoto)

    def check(self):
        #self.takePhoto()
        text = FruitIdentifier().identify(self.image)
        self.label.config(text=text)

App()           
        
        
    
                             
